@@ -108,6 +108,9 @@ enum PERFLIB_PRIO {
     PRIO_MSSQL_DATABASE_LOCKS_TIMEOUT_PER_SECOND,
     PRIO_MSSQL_DATABASE_LOCK_REQUESTS_SEC,
 
+    PRIO_MSSQL_DATABASE_READONLY,
+    PRIO_MSSQL_DATABASE_STATE,
+
     PRIO_MSSQL_DATABASE_DATA_FILE_SIZE,
 
     PRIO_MSSQL_STATS_BATCH_REQUEST,
