@@ -3,7 +3,6 @@
 package snmp
 
 import (
-	"errors"
 	"fmt"
 	"log/slog"
 	"maps"
@@ -25,19 +24,29 @@ import (
 const oidSysUptime = "1.3.6.1.2.1.1.3.0"
 
 func (c *Collector) collect() (map[string]int64, error) {
+	if c.snmpClient == nil {
+		snmpClient, err := c.initAndConnectSNMPClient()
+		if err != nil {
+			return nil, err
+		}
+		c.snmpClient = snmpClient
+		if c.ddSnmpColl != nil {
+			c.ddSnmpColl.SetSNMPClient(snmpClient)
+		}
+	}
+
 	if c.sysInfo == nil {
 		si, err := snmputils.GetSysInfo(c.snmpClient)
 		if err != nil {
 			return nil, err
 		}
 
-		if c.DisableLegacyCollection || c.EnableProfiles {
-			c.snmpProfiles = c.setupProfiles(si.SysObjectID)
+		if c.enableProfiles {
+			c.snmpProfiles = c.setupProfiles(si)
 		}
 
 		if c.ddSnmpColl == nil {
 			c.ddSnmpColl = ddsnmpcollector.New(c.snmpClient, c.snmpProfiles, c.Logger, si.SysObjectID)
-			c.ddSnmpColl.DoTableMetrics = c.EnableProfilesTableMetrics && c.snmpBulkWalkOk
 		}
 
 		if c.CreateVnode {
@@ -49,10 +58,6 @@ func (c *Collector) collect() (map[string]int64, error) {
 		}
 
 		c.sysInfo = si
-
-		if !c.DisableLegacyCollection {
-			c.addSysUptimeChart()
-		}
 	}
 
 	mx := make(map[string]int64)
@@ -61,51 +66,15 @@ func (c *Collector) collect() (map[string]int64, error) {
 		c.Infof("failed to collect profiles: %v", err)
 	}
 
-	if !c.DisableLegacyCollection {
-		if err := c.collectSysUptime(mx); err != nil {
+	if !c.DisableLegacyCollection && len(c.customOids) > 0 {
+		if err := c.collectOIDs(mx); err != nil {
 			return nil, err
 		}
-
-		if c.snmpBulkWalkOk && c.collectIfMib {
-			if err := c.collectNetworkInterfaces(mx); err != nil {
-				return nil, err
-			}
-		}
-		if len(c.customOids) > 0 {
-			if err := c.collectOIDs(mx); err != nil {
-				return nil, err
-			}
-		}
 	}
 
 	return mx, nil
 }
 
-func (c *Collector) collectSysUptime(mx map[string]int64) error {
-	resp, err := c.snmpClient.Get([]string{oidSysUptime})
-	if err != nil {
-		return err
-	}
-	if len(resp.Variables) == 0 {
-		return errors.New("no system uptime")
-	}
-	v, err := pduToInt(resp.Variables[0])
-	if err != nil {
-		return err
-	}
-
-	mx["uptime"] = v / 100 // the time is in hundredths of a second
-
-	return nil
-}
-
-func (c *Collector) walkAll(rootOid string) ([]gosnmp.SnmpPDU, error) {
-	if c.snmpClient.Version() == gosnmp.Version1 {
-		return c.snmpClient.WalkAll(rootOid)
-	}
-	return c.snmpClient.BulkWalkAll(rootOid)
-}
-
 func (c *Collector) setupVnode(si *snmputils.SysInfo, deviceMeta map[string]ddsnmp.MetaTag) *vnodes.VirtualNode {
 	if c.Vnode.GUID == "" {
 		c.Vnode.GUID = uuid.NewSHA1(uuid.NameSpaceDNS, []byte(c.Hostname)).String()
@@ -163,8 +132,8 @@ func (c *Collector) setupVnode(si *snmputils.SysInfo, deviceMeta map[string]ddsn
 	}
 }
 
-func (c *Collector) setupProfiles(sysObjectID string) []*ddsnmp.Profile {
-	snmpProfiles := ddsnmp.FindProfiles(sysObjectID)
+func (c *Collector) setupProfiles(si *snmputils.SysInfo) []*ddsnmp.Profile {
+	snmpProfiles := ddsnmp.FindProfiles(si.SysObjectID, si.Descr, c.ManualProfiles)
 	var profInfo []string
 
 	for _, prof := range snmpProfiles {
@@ -176,12 +145,39 @@ func (c *Collector) setupProfiles(sysObjectID string) []*ddsnmp.Profile {
 		}
 	}
 
-	c.Infof("device matched %d profile(s): %s (sysObjectID: %s)", len(snmpProfiles), strings.Join(profInfo, ", "), sysObjectID)
+	c.Infof("device matched %d profile(s): %s (sysObjectID: '%s')",
+		len(snmpProfiles), strings.Join(profInfo, ", "), si.SysObjectID)
 
 	return snmpProfiles
 }
 
-func (c *Collector) adjustMaxRepetitions() (bool, error) {
+func (c *Collector) initAndConnectSNMPClient() (gosnmp.Handler, error) {
+	snmpClient, err := c.initSNMPClient()
+	if err != nil {
+		return nil, fmt.Errorf("init: %w", err)
+	}
+
+	if err := snmpClient.Connect(); err != nil {
+		return nil, fmt.Errorf("connect: %w", err)
+	}
+
+	if c.adjMaxRepetitions != 0 {
+		snmpClient.SetMaxRepetitions(c.adjMaxRepetitions)
+	} else {
+		ok, err := c.adjustMaxRepetitions(snmpClient)
+		if err != nil {
+			return nil, fmt.Errorf("re-adjust max repetitions SNMP client: %w", err)
+		}
+		if !ok {
+			c.Warningf("SNMP bulk walk disabled: table metrics collection unavailable (device may not support GETBULK or max-repetitions adjustment failed)")
+		}
+		c.adjMaxRepetitions = snmpClient.MaxRepetitions()
+		c.snmpBulkWalkOk = ok
+	}
+
+	return snmpClient, nil
+}
+func (c *Collector) adjustMaxRepetitions(snmpClient gosnmp.Handler) (bool, error) {
 	orig := c.Config.Options.MaxRepetitions
 	maxReps := c.Config.Options.MaxRepetitions
 	attempts := 0
@@ -190,7 +186,7 @@ func (c *Collector) adjustMaxRepetitions() (bool, error) {
 	for maxReps > 0 && attempts < maxAttempts {
 		attempts++
 
-		v, err := c.walkAll(snmputils.RootOidMibSystem)
+		v, err := walkAll(snmpClient, snmputils.RootOidMibSystem)
 		if err != nil {
 			return false, err
 		}
@@ -218,21 +214,28 @@ func (c *Collector) adjustMaxRepetitions() (bool, error) {
 		maxReps = max(0, maxReps) // Ensure non-negative
 
 		c.Debugf("max_repetitions=%d returned no data, trying %d", prevMaxReps, maxReps)
-		c.snmpClient.SetMaxRepetitions(uint32(maxReps))
+		snmpClient.SetMaxRepetitions(uint32(maxReps))
 	}
 
 	// Restore original value since nothing worked
-	c.snmpClient.SetMaxRepetitions(uint32(orig))
+	snmpClient.SetMaxRepetitions(uint32(orig))
 	c.Debugf("unable to find working max_repetitions value after %d attempts", attempts)
 	return false, nil
 }
 
+func walkAll(snmpClient gosnmp.Handler, rootOid string) ([]gosnmp.SnmpPDU, error) {
+	if snmpClient.Version() == gosnmp.Version1 {
+		return snmpClient.WalkAll(rootOid)
+	}
+	return snmpClient.BulkWalkAll(rootOid)
+}
+
 func pduToInt(pdu gosnmp.SnmpPDU) (int64, error) {
 	switch pdu.Type {
 	case gosnmp.Counter32, gosnmp.Counter64, gosnmp.Integer, gosnmp.Gauge32, gosnmp.TimeTicks:
 		return gosnmp.ToBigInt(pdu.Value).Int64(), nil
 	default:
-		return 0, fmt.Errorf("unussported type: '%v'", pdu.Type)
+		return 0, fmt.Errorf("unsupported type: '%v'", pdu.Type)
 	}
 }
 
