@@ -6,8 +6,10 @@
 package ddprofiledefinition
 
 import (
+	"errors"
 	"fmt"
 	"regexp"
+	"slices"
 )
 
 var validMetadataResources = map[string]map[string]bool{
@@ -48,70 +50,68 @@ const (
 )
 
 // ValidateEnrichProfile validates a profile and normalizes it.
-func ValidateEnrichProfile(profile *ProfileDefinition) []string {
-	NormalizeMetrics(profile.Metrics)
-	// migrate legacy profile.Device.Vendor to metadata field.
-	// TODO this is commented out because it changes existing behavior; uncomment when we want to support this properly.
-	// if profile.Device.Vendor != "" {
-	// 	dev, ok := profile.Metadata["device"]
-	// 	if !ok {
-	// 		profile.Metadata["device"] = MetadataResourceConfig{
-	// 			Fields: make(map[string]MetadataField),
-	// 		}
-	// 		dev = profile.Metadata["device"]
-	// 	}
-	// 	_, ok = dev.Fields["vendor"]
-	// 	if !ok {
-	// 		dev.Fields["vendor"] = MetadataField{
-	// 			Value: profile.Device.Vendor,
-	// 		}
-	// 	}
-	// 	profile.Device.Vendor = ""
-	// }
-	errors := ValidateEnrichMetadata(profile.Metadata)
-	errors = append(errors, ValidateEnrichMetrics(profile.Metrics)...)
-	errors = append(errors, ValidateEnrichMetricTags(profile.MetricTags)...)
-	return errors
+func ValidateEnrichProfile(p *ProfileDefinition) error {
+	NormalizeMetrics(p.Metrics)
+
+	var errs []error
+
+	if err := validateEnrichLegacySelector(p); err != nil {
+		errs = append(errs, err)
+	}
+	for _, err := range ValidateEnrichMetadata(p.Metadata) {
+		errs = append(errs, errors.New(err))
+	}
+	for _, err := range ValidateEnrichSysobjectIDMetadata(p.SysobjectIDMetadata) {
+		errs = append(errs, errors.New(err))
+	}
+	for _, err := range ValidateEnrichMetrics(p.Metrics) {
+		errs = append(errs, errors.New(err))
+	}
+	for _, err := range ValidateEnrichMetricTags(p.MetricTags) {
+		errs = append(errs, errors.New(err))
+	}
+
+	return errors.Join(errs...)
 }
 
 // ValidateEnrichMetricTags validates and normalizes metric tags
 func ValidateEnrichMetricTags(metricTags []MetricTagConfig) []string {
-	var errors []string
+	var errs []string
 	for i := range metricTags {
-		errors = append(errors, validateEnrichMetricTag(&metricTags[i])...)
+		errs = append(errs, validateEnrichMetricTag(&metricTags[i])...)
 	}
-	return errors
+	return errs
 }
 
 // ValidateEnrichMetrics will validate MetricsConfig and enrich it.
 // Example of enrichment:
 // - storage of compiled regex pattern
 func ValidateEnrichMetrics(metrics []MetricsConfig) []string {
-	var errors []string
+	var errs []string
 	for i := range metrics {
 		metricConfig := &metrics[i]
 		if !metricConfig.IsScalar() && !metricConfig.IsColumn() {
-			errors = append(errors, fmt.Sprintf("either a table symbol or a scalar symbol must be provided: %#v", metricConfig))
+			errs = append(errs, fmt.Sprintf("either a table symbol or a scalar symbol must be provided: %#v", metricConfig))
 		}
 		if metricConfig.IsScalar() && metricConfig.IsColumn() {
-			errors = append(errors, fmt.Sprintf("table symbol and scalar symbol cannot be both provided: %#v", metricConfig))
+			errs = append(errs, fmt.Sprintf("table symbol and scalar symbol cannot be both provided: %#v", metricConfig))
 		}
 		if metricConfig.IsScalar() {
-			errors = append(errors, validateEnrichSymbol(&metricConfig.Symbol, ScalarSymbol)...)
+			errs = append(errs, validateEnrichSymbol(&metricConfig.Symbol, ScalarSymbol)...)
 		}
 		if metricConfig.IsColumn() {
 			for j := range metricConfig.Symbols {
-				errors = append(errors, validateEnrichSymbol(&metricConfig.Symbols[j], ColumnSymbol)...)
+				errs = append(errs, validateEnrichSymbol(&metricConfig.Symbols[j], ColumnSymbol)...)
 			}
 			if len(metricConfig.MetricTags) == 0 {
-				errors = append(errors, fmt.Sprintf("column symbols doesn't have a 'metric_tags' section (%+v), all its metrics will use the same tags; "+
+				errs = append(errs, fmt.Sprintf("column symbols doesn't have a 'metric_tags' section (%+v), all its metrics will use the same tags; "+
 					"if the table has multiple rows, only one row will be submitted; "+
 					"please add at least one discriminating metric tag (such as a row index) "+
 					"to ensure metrics of all rows are submitted", metricConfig.Symbols))
 			}
 			for i := range metricConfig.MetricTags {
 				metricTag := &metricConfig.MetricTags[i]
-				errors = append(errors, validateEnrichMetricTag(metricTag)...)
+				errs = append(errs, validateEnrichMetricTag(metricTag)...)
 			}
 		}
 		// Setting forced_type value to metric_type value for backward compatibility
@@ -120,48 +120,48 @@ func ValidateEnrichMetrics(metrics []MetricsConfig) []string {
 		}
 		metricConfig.ForcedType = ""
 	}
-	return errors
+	return errs
 }
 
 // ValidateEnrichMetadata will validate MetadataConfig and enrich it.
 func ValidateEnrichMetadata(metadata MetadataConfig) []string {
-	var errors []string
+	var errs []string
 	for resName := range metadata {
 		_, isValidRes := validMetadataResources[resName]
 		if !isValidRes {
-			errors = append(errors, fmt.Sprintf("invalid resource: %s", resName))
+			errs = append(errs, fmt.Sprintf("invalid resource: %s", resName))
 		} else {
 			res := metadata[resName]
 			for fieldName := range res.Fields {
 				_, isValidField := validMetadataResources[resName][fieldName]
 				if !isValidField {
-					errors = append(errors, fmt.Sprintf("invalid resource (%s) field: %s", resName, fieldName))
+					errs = append(errs, fmt.Sprintf("invalid resource (%s) field: %s", resName, fieldName))
 					continue
 				}
 				field := res.Fields[fieldName]
 				for i := range field.Symbols {
-					errors = append(errors, validateEnrichSymbol(&field.Symbols[i], MetadataSymbol)...)
+					errs = append(errs, validateEnrichSymbol(&field.Symbols[i], MetadataSymbol)...)
 				}
 				if field.Symbol.OID != "" {
-					errors = append(errors, validateEnrichSymbol(&field.Symbol, MetadataSymbol)...)
+					errs = append(errs, validateEnrichSymbol(&field.Symbol, MetadataSymbol)...)
 				}
 				res.Fields[fieldName] = field
 			}
 			metadata[resName] = res
 		}
 		if resName == "device" && len(metadata[resName].IDTags) > 0 {
-			errors = append(errors, "device resource does not support custom id_tags")
+			errs = append(errs, "device resource does not support custom id_tags")
 		}
 		for i := range metadata[resName].IDTags {
 			metricTag := &metadata[resName].IDTags[i]
-			errors = append(errors, validateEnrichMetricTag(metricTag)...)
+			errs = append(errs, validateEnrichMetricTag(metricTag)...)
 		}
 	}
-	return errors
+	return errs
 }
 
 func ValidateEnrichSysobjectIDMetadata(entries []SysobjectIDMetadataEntryConfig) []string {
-	var errors []string
+	var errs []string
 
 	// Track seen sysobjectids to detect duplicates
 	seenOIDs := make(map[string]int) // OID -> first occurrence index
@@ -169,13 +169,13 @@ func ValidateEnrichSysobjectIDMetadata(entries []SysobjectIDMetadataEntryConfig)
 	for i, entry := range entries {
 		// Validate sysobjectid is not empty
 		if entry.SysobjectID == "" {
-			errors = append(errors, fmt.Sprintf("sysobjectid_metadata[%d]: missing sysobjectid", i))
+			errs = append(errs, fmt.Sprintf("sysobjectid_metadata[%d]: missing sysobjectid", i))
 			continue
 		}
 
 		// Check for duplicate sysobjectids
 		if firstIdx, exists := seenOIDs[entry.SysobjectID]; exists {
-			errors = append(errors, fmt.Sprintf("sysobjectid_metadata[%d]: duplicate sysobjectid %s (first occurrence at index %d)",
+			errs = append(errs, fmt.Sprintf("sysobjectid_metadata[%d]: duplicate sysobjectid %s (first occurrence at index %d)",
 				i, entry.SysobjectID, firstIdx))
 		} else {
 			seenOIDs[entry.SysobjectID] = i
@@ -185,19 +185,19 @@ func ValidateEnrichSysobjectIDMetadata(entries []SysobjectIDMetadataEntryConfig)
 		for fieldName, field := range entry.Metadata {
 			// Validate the field must have either value or symbol(s)
 			if field.Value == "" && field.Symbol.OID == "" && len(field.Symbols) == 0 {
-				errors = append(errors, fmt.Sprintf("sysobjectid_metadata[%d].%s: must have either value or symbol(s)", i, fieldName))
+				errs = append(errs, fmt.Sprintf("sysobjectid_metadata[%d].%s: must have either value or symbol(s)", i, fieldName))
 			}
 
 			// Can't have both value and symbols
 			if field.Value != "" && (field.Symbol.OID != "" || len(field.Symbols) > 0) {
-				errors = append(errors, fmt.Sprintf("sysobjectid_metadata[%d].%s: cannot have both value and symbol(s)", i, fieldName))
+				errs = append(errs, fmt.Sprintf("sysobjectid_metadata[%d].%s: cannot have both value and symbol(s)", i, fieldName))
 			}
 
 			// Validate symbols if present
 			for j := range field.Symbols {
 				symbolErrors := validateEnrichSymbol(&field.Symbols[j], MetadataSymbol)
 				for _, err := range symbolErrors {
-					errors = append(errors, fmt.Sprintf("sysobjectid_metadata[%d].%s.symbols[%d]: %s", i, fieldName, j, err))
+					errs = append(errs, fmt.Sprintf("sysobjectid_metadata[%d].%s.symbols[%d]: %s", i, fieldName, j, err))
 				}
 			}
 
@@ -205,7 +205,7 @@ func ValidateEnrichSysobjectIDMetadata(entries []SysobjectIDMetadataEntryConfig)
 			if field.Symbol.OID != "" {
 				symbolErrors := validateEnrichSymbol(&field.Symbol, MetadataSymbol)
 				for _, err := range symbolErrors {
-					errors = append(errors, fmt.Sprintf("sysobjectid_metadata[%d].%s.symbol: %s", i, fieldName, err))
+					errs = append(errs, fmt.Sprintf("sysobjectid_metadata[%d].%s.symbol: %s", i, fieldName, err))
 				}
 			}
 
@@ -213,25 +213,25 @@ func ValidateEnrichSysobjectIDMetadata(entries []SysobjectIDMetadataEntryConfig)
 		}
 	}
 
-	return errors
+	return errs
 }
 
 func validateEnrichSymbol(symbol *SymbolConfig, symbolContext SymbolContext) []string {
-	var errors []string
+	var errs []string
 	if symbol.Name == "" {
-		errors = append(errors, fmt.Sprintf("symbol name missing: name=`%s` oid=`%s`", symbol.Name, symbol.OID))
+		errs = append(errs, fmt.Sprintf("symbol name missing: name=`%s` oid=`%s`", symbol.Name, symbol.OID))
 	}
 	if symbol.OID == "" {
 		if symbolContext == ColumnSymbol && !symbol.ConstantValueOne {
-			errors = append(errors, fmt.Sprintf("symbol oid or send_as_one missing: name=`%s` oid=`%s`", symbol.Name, symbol.OID))
+			errs = append(errs, fmt.Sprintf("symbol oid or send_as_one missing: name=`%s` oid=`%s`", symbol.Name, symbol.OID))
 		} else if symbolContext != ColumnSymbol {
-			errors = append(errors, fmt.Sprintf("symbol oid missing: name=`%s` oid=`%s`", symbol.Name, symbol.OID))
+			errs = append(errs, fmt.Sprintf("symbol oid missing: name=`%s` oid=`%s`", symbol.Name, symbol.OID))
 		}
 	}
 	if symbol.ExtractValue != "" {
 		pattern, err := regexp.Compile(symbol.ExtractValue)
 		if err != nil {
-			errors = append(errors, fmt.Sprintf("cannot compile `extract_value` (%s): %s", symbol.ExtractValue, err.Error()))
+			errs = append(errs, fmt.Sprintf("cannot compile `extract_value` (%s): %s", symbol.ExtractValue, err.Error()))
 		} else {
 			symbol.ExtractValueCompiled = pattern
 		}
@@ -239,23 +239,24 @@ func validateEnrichSymbol(symbol *SymbolConfig, symbolContext SymbolContext) []s
 	if symbol.MatchPattern != "" {
 		pattern, err := regexp.Compile(symbol.MatchPattern)
 		if err != nil {
-			errors = append(errors, fmt.Sprintf("cannot compile `extract_value` (%s): %s", symbol.ExtractValue, err.Error()))
+			errs = append(errs, fmt.Sprintf("cannot compile `extract_value` (%s): %s", symbol.ExtractValue, err.Error()))
 		} else {
 			symbol.MatchPatternCompiled = pattern
 		}
 	}
 	if symbolContext != ColumnSymbol && symbol.ConstantValueOne {
-		errors = append(errors, "`constant_value_one` cannot be used outside of tables")
+		errs = append(errs, "`constant_value_one` cannot be used outside of tables")
 	}
 	if (symbolContext != ColumnSymbol && symbolContext != ScalarSymbol) && symbol.MetricType != "" {
-		errors = append(errors, "`metric_type` cannot be used outside scalar/table metric symbols and metrics root")
+		errs = append(errs, "`metric_type` cannot be used outside scalar/table metric symbols and metrics root")
 	}
-	return errors
+	return errs
 }
+
 func validateEnrichMetricTag(metricTag *MetricTagConfig) []string {
-	var errors []string
+	var errs []string
 	if (metricTag.Column.OID != "" || metricTag.Column.Name != "") && (metricTag.Symbol.OID != "" || metricTag.Symbol.Name != "") {
-		errors = append(errors, fmt.Sprintf("metric tag symbol and column cannot be both declared: symbol=%v, column=%v", metricTag.Symbol, metricTag.Column))
+		errs = append(errs, fmt.Sprintf("metric tag symbol and column cannot be both declared: symbol=%v, column=%v", metricTag.Symbol, metricTag.Column))
 	}
 
 	// Move deprecated metricTag.Column to metricTag.Symbol
@@ -272,7 +273,7 @@ func validateEnrichMetricTag(metricTag *MetricTagConfig) []string {
 	// this will lead to OID stored as MetricTagConfig.OID  and name stored as MetricTagConfig.Symbol.Name
 	// When this happens, we harmonize by moving MetricTagConfig.OID to MetricTagConfig.Symbol.OID.
 	if metricTag.OID != "" && metricTag.Symbol.OID != "" {
-		errors = append(errors, fmt.Sprintf("metric tag OID and symbol.OID cannot be both declared: OID=%s, symbol.OID=%s", metricTag.OID, metricTag.Symbol.OID))
+		errs = append(errs, fmt.Sprintf("metric tag OID and symbol.OID cannot be both declared: OID=%s, symbol.OID=%s", metricTag.OID, metricTag.Symbol.OID))
 	}
 	if metricTag.OID != "" && metricTag.Symbol.OID == "" {
 		metricTag.Symbol.OID = metricTag.OID
@@ -280,27 +281,63 @@ func validateEnrichMetricTag(metricTag *MetricTagConfig) []string {
 	}
 	if metricTag.Symbol.OID != "" || metricTag.Symbol.Name != "" {
 		symbol := SymbolConfig(metricTag.Symbol)
-		errors = append(errors, validateEnrichSymbol(&symbol, MetricTagSymbol)...)
+		errs = append(errs, validateEnrichSymbol(&symbol, MetricTagSymbol)...)
 		metricTag.Symbol = SymbolConfigCompat(symbol)
 	}
 	if metricTag.Match != "" {
 		pattern, err := regexp.Compile(metricTag.Match)
 		if err != nil {
-			errors = append(errors, fmt.Sprintf("cannot compile `match` (`%s`): %s", metricTag.Match, err.Error()))
+			errs = append(errs, fmt.Sprintf("cannot compile `match` (`%s`): %s", metricTag.Match, err.Error()))
 		} else {
 			metricTag.Pattern = pattern
 		}
 		if len(metricTag.Tags) == 0 {
-			errors = append(errors, fmt.Sprintf("`tags` mapping must be provided if `match` (`%s`) is defined", metricTag.Match))
+			errs = append(errs, fmt.Sprintf("`tags` mapping must be provided if `match` (`%s`) is defined", metricTag.Match))
 		}
 	}
 	if len(metricTag.Mapping) > 0 && metricTag.Tag == "" {
-		errors = append(errors, fmt.Sprintf("``tag` must be provided if `mapping` (`%s`) is defined", metricTag.Mapping))
+		errs = append(errs, fmt.Sprintf("``tag` must be provided if `mapping` (`%s`) is defined", metricTag.Mapping))
 	}
 	for _, transform := range metricTag.IndexTransform {
 		if transform.Start > transform.End {
-			errors = append(errors, fmt.Sprintf("transform rule end should be greater than start. Invalid rule: %#v", transform))
+			errs = append(errs, fmt.Sprintf("transform rule end should be greater than start. Invalid rule: %#v", transform))
 		}
 	}
-	return errors
+	return errs
+}
+
+// validateEnrichLegacySelector migrates legacy sysobjectid into selector include/exclude
+// and validates that all OID patterns compile as regex.
+func validateEnrichLegacySelector(p *ProfileDefinition) error {
+	var errs []error
+
+	// If the new selector is absent but legacy sysobjectid exists, migrate it.
+	if len(p.Selector) == 0 && len(p.SysObjectIDs) > 0 {
+		p.Selector = SelectorSpec{
+			{
+				SysObjectID: SelectorIncludeExclude{
+					Include: slices.Clone(p.SysObjectIDs), // legacy -> include
+				},
+			},
+		}
+	}
+
+	// Normalize and validate every rule
+	for i := range p.Selector {
+		r := &p.Selector[i]
+
+		// Validate regex syntax for sysObjectID includes/excludes
+		for j, pat := range r.SysObjectID.Include {
+			if _, err := regexp.Compile(pat); err != nil {
+				errs = append(errs, fmt.Errorf("selector[%d].sysObjectID.include[%d]: invalid regex %q: %v", i, j, pat, err))
+			}
+		}
+		for j, pat := range r.SysObjectID.Exclude {
+			if _, err := regexp.Compile(pat); err != nil {
+				errs = append(errs, fmt.Errorf("selector[%d].sysObjectID.exclude[%d]: invalid regex %q: %v", i, j, pat, err))
+			}
+		}
+	}
+
+	return errors.Join(errs...)
 }
